# Cornojob Killer

Cornojob

*noun*

1. An extremely repetitive and boring task that no one likes doing.
2. Killer of innovation and scale
3. A symptom of bad tooling


## Install
```python
pip install cornojob-killer
```

## Usage
```python
cornojob kill
```
